Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(977)

Unified Diff: src/frames.h

Issue 1442643002: [turbofan] Rename "original constructor" to "new target". (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Rebased. Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/js-inlining.cc ('k') | src/frames.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/frames.h
diff --git a/src/frames.h b/src/frames.h
index f00cbdb887d1062ebd0e49a8e19797ab1ea6d65d..994ca5480a94a8ad2199941c54f178112a181e6b 100644
--- a/src/frames.h
+++ b/src/frames.h
@@ -162,7 +162,7 @@ class ConstructFrameConstants : public AllStatic {
// FP-relative.
static const int kImplicitReceiverOffset =
StandardFrameConstants::kExpressionsOffset - 4 * kPointerSize;
- static const int kOriginalConstructorOffset =
+ static const int kNewTargetOffset =
StandardFrameConstants::kExpressionsOffset - 3 * kPointerSize;
static const int kLengthOffset =
StandardFrameConstants::kExpressionsOffset - 2 * kPointerSize;
@@ -583,9 +583,9 @@ class JavaScriptFrame: public StandardFrame {
// about the inlined frames use {GetFunctions} and {Summarize}.
bool HasInlinedFrames() const;
- // Returns the original constructor function that was used in the constructor
- // call to this frame. Note that this is only valid on constructor frames.
- Object* GetOriginalConstructor() const;
+ // Returns the new target function that was used in the constructor call to
+ // this frame. Note that this is only valid on constructor frames.
+ Object* GetNewTarget() const;
// Check if this frame has "adapted" arguments in the sense that the
// actual passed arguments are available in an arguments adaptor
« no previous file with comments | « src/compiler/js-inlining.cc ('k') | src/frames.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698